@@ -5,7 +5,7 @@
  * libradius.h	Structures and prototypes
  *		for the radius library.
  *
- * Version:	$Id: libradius.h,v 1.76.2.2.2.3 2005/12/12 23:28:29 aland Exp $
+ * Version:	$Id: libradius.h,v 1.76.2.2.2.8 2006/05/16 18:26:06 aland Exp $
  *
  */
 
@@ -98,10 +98,10 @@
 typedef struct attr_flags {
 	char			addport;	/* Add port to IP address */
 	char			has_tag;	/* attribute allows tags */
-	signed char		tag;
-	uint8_t		        encrypt;	/* encryption method */
 	signed char		len_disp;	/* length displacement */
 	char			do_xlat;
+	signed char		tag;
+	uint8_t		        encrypt;	/* encryption method */
 } ATTR_FLAGS;
 
 /*
@@ -238,6 +238,7 @@ void lrad_hmac_sha1(const unsigned char *text, int text_len,
 /* radius.c */
 int		rad_send(RADIUS_PACKET *, const RADIUS_PACKET *, const char *secret);
 RADIUS_PACKET	*rad_recv(int fd);
+int		rad_verify(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secret);
 int		rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secret);
 RADIUS_PACKET	*rad_alloc(int newvector);
 void		rad_free(RADIUS_PACKET **);
@@ -311,6 +312,9 @@ int		rad_lockfd_nonblock(int fd, int lock_len);
 int		rad_unlockfd(int fd, int lock_len);
 void		lrad_bin2hex(const uint8_t *bin, char *hex, int len);
 int		lrad_hex2bin(const char *hex, uint8_t *bin, int len);
+#ifndef HAVE_CLOSEFROM
+int		closefrom(int fd);
+#endif
 
 #ifdef ASCEND_BINARY
 /* filters.c */
@@ -372,6 +376,7 @@ int rbtree_walk(rbtree_t *tree, RBTREE_ORDER order, int (*callback)(void *, void
  */
 uint32_t lrad_hash(const void *, size_t);
 uint32_t lrad_hash_update(const void *data, size_t size, uint32_t hash);
+uint32_t lrad_hash_string(const char *p);
 
 /*
  *	If you need fewer than 32-bits of hash, use this macro to get
@@ -381,19 +386,18 @@ uint32_t lrad_hash_update(const void *data, size_t size, uint32_t hash);
 uint32_t lrad_hash_fold(uint32_t hash, int bits);
 
 typedef struct lrad_hash_table_t lrad_hash_table_t;
+typedef void (*lrad_hash_table_free_t)(void *);
+typedef int (*lrad_hash_table_walk_t)(void * /* ctx */, void * /* data */);
 
-lrad_hash_table_t *lrad_hash_table_create(int size, void (*freeNode)(void *),
-					  int replace_flag);
+lrad_hash_table_t *lrad_hash_table_create(lrad_hash_table_free_t freeNode);
 void		lrad_hash_table_free(lrad_hash_table_t *ht);
-int		lrad_hash_table_insert(lrad_hash_table_t *ht, uint32_t key,
-				       void *data);
+int		lrad_hash_table_insert(lrad_hash_table_t *ht, uint32_t key, void *data);
 int		lrad_hash_table_delete(lrad_hash_table_t *ht, uint32_t key);
+void		*lrad_hash_table_yank(lrad_hash_table_t *ht, uint32_t key);
+int		lrad_hash_table_replace(lrad_hash_table_t *ht, uint32_t key, void *data);
 void		*lrad_hash_table_finddata(lrad_hash_table_t *ht, uint32_t key);
 int		lrad_hash_table_num_elements(lrad_hash_table_t *ht);
 int		lrad_hash_table_walk(lrad_hash_table_t *ht,
-				     int (*callback)(void * /* ctx */,
-						     void * /* data */),
-				     void *context);
-int		lrad_hash_table_set_data_size(lrad_hash_table_t *ht,
-					      size_t data_size);
+				     lrad_hash_table_walk_t callback,
+				     void *ctx);
 #endif /*LIBRADIUS_H*/
