@@ -1,7 +1,7 @@
 /*
  * radius.h	Constants of the radius protocol.
  *
- * Version:	$Id: radius.h,v 1.66 2004/04/30 18:23:08 aland Exp $
+ * Version:	$Id: radius.h,v 1.66.4.2 2006/03/07 18:10:08 aland Exp $
  *
  */
 
@@ -32,9 +32,9 @@
 #define PW_DISCONNECT_REQUEST		40
 #define PW_DISCONNECT_ACK		41
 #define PW_DISCONNECT_NAK		42
-#define PW_COF_REQUEST			43
-#define PW_COF_ACK			44
-#define PW_COF_NAK			45
+#define PW_COA_REQUEST			43
+#define PW_COA_ACK			44
+#define PW_COA_NAK			45
 
 #define PW_AUTH_UDP_PORT                1812
 #define PW_ACCT_UDP_PORT                1813
@@ -111,6 +111,7 @@
 #define PW_ARAP_CHALLENGE_RESPONSE	84
 #define PW_NAS_PORT_ID_STRING  		87
 #define PW_FRAMED_POOL			88
+#define PW_NAS_IPV6_ADDRESS		95
 
 #define PW_DIGEST_RESPONSE		206
 #define PW_DIGEST_ATTRIBUTES		207
@@ -179,12 +180,26 @@
 #define PW_LDAP_GROUP			1074
 #define PW_MODULE_SUCCESS_MESSAGE	1075
 #define PW_MODULE_FAILURE_MESSAGE	1076
+#if 0 /* no longer used */
 #define PW_X99_FAST			1077
+#endif
 #define PW_REWRITE_RULE			1078
 #define PW_SQL_GROUP			1079
 #define PW_RESPONSE_PACKET_TYPE		1080
-#define PW_PACKET_DST_PORT		1081
+#define PW_DIGEST_HA1			1081
 #define PW_MS_CHAP_USE_NTLM_AUTH	1082
+#define PW_PACKET_SRC_IP_ADDRESS	1084
+#define PW_PACKET_DST_IP_ADDRESS	1085
+#define PW_PACKET_SRC_PORT		1086
+#define PW_PACKET_DST_PORT		1087
+#define PW_PACKET_AUTHENTICATION_VECTOR	1088
+#define PW_TIME_OF_DAY			1089
+
+#define PW_SHA_PASSWORD			1093
+#define PW_SSHA_PASSWORD		1094
+#define PW_MD5_PASSWORD			1095
+#define PW_SMD5_PASSWORD		1096
+
 
 /*
  *	Integer Translations
