@@ -1,7 +1,7 @@
 /*
  * dict.c	Routines to read the dictionary file.
  *
- * Version:	$Id: dict.c,v 1.50.2.4.2.4 2006/03/15 15:37:54 nbk Exp $
+ * Version:	$Id: dict.c,v 1.50.2.4.2.9 2006/05/19 16:21:44 aland Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: dict.c,v 1.50.2.4.2.4 2006/03/15 15:37:54 nbk Exp $";
+static const char rcsid[] = "$Id: dict.c,v 1.50.2.4.2.9 2006/05/19 16:21:44 aland Exp $";
 
 #include	"autoconf.h"
 
@@ -251,7 +251,7 @@ int dict_addvendor(const char *name, int value)
 	dv->vendorpec  = value;
 	dv->type = dv->length = 1; /* defaults */
 
-	if (lrad_hash_table_insert(vendors_byname, hash, dv) == 0) {
+	if (!lrad_hash_table_insert(vendors_byname, hash, dv)) {
 		DICT_VENDOR *old_dv;
 
 		old_dv = lrad_hash_table_finddata(vendors_byname, hash);
@@ -275,17 +275,19 @@ int dict_addvendor(const char *name, int value)
 	 *	Insert the SAME pointer (not free'd when this tree is
 	 *	deleted), into another tree.
 	 *
-	 *	If the newly inserted entry is a duplicate of an existing
-	 *	entry, then the old entry is tossed, and the new one
-	 *	replaces it.  This behaviour is configured in the
-	 *	lrad_hash_table_create() function.
-	 *
 	 *	We want this behaviour because we want OLD names for
 	 *	the attributes to be read from the configuration
 	 *	files, but when we're printing them, (and looking up
 	 *	by value) we want to use the NEW name.
 	 */
-	lrad_hash_table_insert(vendors_byvalue, dv->vendorpec, dv);
+	if (!lrad_hash_table_replace(vendors_byvalue,
+				    lrad_hash(&dv->vendorpec,
+					      sizeof(dv->vendorpec)),
+				    dv)) {
+		librad_log("dict_addvendor: Failed inserting vendor %s",
+			   name);
+		return -1;
+	}
 
 	return 0;
 }
@@ -379,7 +381,7 @@ int dict_addattr(const char *name, int vendor, int type, int value,
 	/*
 	 *	Insert the attribute, only if it's not a duplicate.
 	 */
-	if (lrad_hash_table_insert(attributes_byname, hash, attr) == 0) {
+	if (!lrad_hash_table_insert(attributes_byname, hash, attr)) {
 		DICT_ATTR	*a;
 
 		/*
@@ -406,17 +408,17 @@ int dict_addattr(const char *name, int vendor, int type, int value,
 	 *	Insert the SAME pointer (not free'd when this tree is
 	 *	deleted), into another tree.
 	 *
-	 *	If the newly inserted entry is a duplicate of an existing
-	 *	entry, then the old entry is tossed, and the new one
-	 *	replaces it.  This behaviour is configured in the
-	 *	lrad_hash_table_create() function.
-	 *
 	 *	We want this behaviour because we want OLD names for
 	 *	the attributes to be read from the configuration
 	 *	files, but when we're printing them, (and looking up
 	 *	by value) we want to use the NEW name.
 	 */
-	lrad_hash_table_insert(attributes_byvalue, (uint32_t) attr->attr, attr);
+	if (!lrad_hash_table_replace(attributes_byvalue,
+				    lrad_hash(&attr->attr, sizeof(attr->attr)),
+				    attr)) {
+		librad_log("dict_addattr: Failed inserting attribute name %s", name);
+		return -1;
+	}
 
 	return 0;
 }
@@ -481,7 +483,7 @@ int dict_addvalue(const char *namestr, const char *attrstr, int value)
 	/*
 	 *	Add the value into the dictionary.
 	 */
-	if (lrad_hash_table_insert(values_byname, hash, dval) == 0) {
+	if (!lrad_hash_table_insert(values_byname, hash, dval)) {
 		if (dattr) {
 			DICT_VALUE *old;
 			
@@ -507,7 +509,11 @@ int dict_addvalue(const char *namestr, const char *attrstr, int value)
 	 */
 	hash = dval->attr;
 	hash = lrad_hash_update(&dval->value, sizeof(dval->value), hash);
-	lrad_hash_table_insert(values_byvalue, hash, dval);
+	if (!lrad_hash_table_replace(values_byvalue, hash, dval)) {	
+		librad_log("dict_addvalue: Failed inserting value %s",
+			   namestr);
+		return -1;
+	}
 
 	return 0;
 }
@@ -606,15 +612,6 @@ static int process_attribute(const char* fn, const int line,
 	 *	difficult.
 	 */
 	if (flags.has_tag) {
-		/*
-		 *	VSA's can't be tagged.
-		 */
-		if (vendor) {
-			librad_log("dict_init: %s[%d]: Vendor attributes cannot be tagged.",
-				   fn, line);
-			return -1;
-		}
-
 		/*
 		 *	Only string, octets, and integer can be tagged.
 		 */
@@ -882,6 +879,12 @@ static int my_dict_init(const char *dir, const char *fn,
 	}
 
 	stat(fn, &statbuf); /* fopen() guarantees this will succeed */
+	if (!S_ISREG(statbuf.st_mode)) {
+		fclose(fp);
+		librad_log("dict_init: Dictionary \"%s\" is not a regular file",
+			   fn);
+		return -1;	  
+	}
 	dict_stat_add(fn, &statbuf);
 
 	/*
@@ -1060,7 +1063,7 @@ int dict_init(const char *dir, const char *fn)
 	 *
 	 *	Each vendor is malloc'd, so the free function is free.
 	 */
-	vendors_byname = lrad_hash_table_create(8, free, 0);
+	vendors_byname = lrad_hash_table_create(free);
 	if (!vendors_byname) {
 		return -1;
 	}
@@ -1070,7 +1073,7 @@ int dict_init(const char *dir, const char *fn)
 	 *	be vendors of the same value.  If there are, we
 	 *	pick the latest one.
 	 */
-	vendors_byvalue = lrad_hash_table_create(8, NULL, 1);
+	vendors_byvalue = lrad_hash_table_create(NULL);
 	if (!vendors_byvalue) {
 		return -1;
 	}
@@ -1081,7 +1084,7 @@ int dict_init(const char *dir, const char *fn)
 	 *
 	 *	Each attribute is malloc'd, so the free function is free.
 	 */
-	attributes_byname = lrad_hash_table_create(11, free, 0);
+	attributes_byname = lrad_hash_table_create(free);
 	if (!attributes_byname) {
 		return -1;
 	}
@@ -1091,17 +1094,17 @@ int dict_init(const char *dir, const char *fn)
 	 *	be attributes of the same value.  If there are, we
 	 *	pick the latest one.
 	 */
-	attributes_byvalue = lrad_hash_table_create(11, NULL, 1);
+	attributes_byvalue = lrad_hash_table_create(NULL);
 	if (!attributes_byvalue) {
 		return -1;
 	}
 
-	values_byname = lrad_hash_table_create(11, free, 0);
+	values_byname = lrad_hash_table_create(free);
 	if (!values_byname) {
 		return -1;
 	}
 
-	values_byvalue = lrad_hash_table_create(11, NULL, 1);
+	values_byvalue = lrad_hash_table_create(NULL);
 	if (!values_byvalue) {
 		return -1;
 	}
@@ -1135,8 +1138,8 @@ int dict_init(const char *dir, const char *fn)
 			hash = lrad_hash_update(&this->dval->attr,
 						sizeof(this->dval->attr),
 						this->hash);
-			if (lrad_hash_table_insert(values_byname,
-						   hash, this->dval) == 0) {
+			if (!lrad_hash_table_replace(values_byname,
+						     hash, this->dval)) {
 				librad_log("dict_addvalue: Duplicate value name %s for attribute %s", this->dval->name, a->name);
 				return -1;
 			}
@@ -1146,13 +1149,14 @@ int dict_init(const char *dir, const char *fn)
 			 *	prefer the new name when printing
 			 *	values.
 			 */
-			hash = (uint32_t) this->dval->attr;
+			hash = lrad_hash(&this->dval->attr,
+					 sizeof(this->dval->attr));
 			hash = lrad_hash_update(&this->dval->value,
 						sizeof(this->dval->value),
 						hash);
 			if (!lrad_hash_table_finddata(values_byvalue, hash)) {
-				lrad_hash_table_insert(values_byvalue,
-						       hash, this->dval);
+				lrad_hash_table_replace(values_byvalue,
+							hash, this->dval);
 			}
 			free(this);
 
@@ -1171,7 +1175,8 @@ int dict_init(const char *dir, const char *fn)
  */
 DICT_ATTR *dict_attrbyvalue(int val)
 {
-	return lrad_hash_table_finddata(attributes_byvalue, (uint32_t) val);
+	return lrad_hash_table_finddata(attributes_byvalue,
+					lrad_hash(&val, sizeof(val)));
 }
 
 /*
@@ -1191,10 +1196,26 @@ DICT_ATTR *dict_attrbyname(const char *name)
 DICT_VALUE *dict_valbyattr(int attr, int val)
 {
 	uint32_t hash = attr;
+	DICT_VALUE *dval;
 
 	hash = lrad_hash_update(&val, sizeof(val), hash);
 
-	return lrad_hash_table_finddata(values_byvalue, hash);
+	dval = lrad_hash_table_finddata(values_byvalue, hash);
+	if (!dval) return NULL;
+
+	/*
+	 *	We may have hash collisions, as the hash table doesn't
+	 *	have a "cmp" function.  So when we look up attributes
+	 *	which have 2^32 possible values, we WILL get a
+	 *	collision.
+	 *
+	 *	Avoid that here by doing a last sanity check before
+	 *	returning the pointer.
+	 */
+	if ((dval->attr != attr) ||
+	    (dval->value != val)) return NULL;
+
+	return dval;
 }
 
 /*
@@ -1237,5 +1258,6 @@ int dict_vendorbyname(const char *name)
  */
 DICT_VENDOR *dict_vendorbyvalue(int vendor)
 {
-	return lrad_hash_table_finddata(vendors_byvalue, (uint32_t) vendor);
+	return lrad_hash_table_finddata(vendors_byvalue,
+					lrad_hash(&vendor, sizeof(vendor)));
 }
