@@ -1,7 +1,7 @@
 /*
  * filters.c	Routines to parse Ascend's filter attributes.
  *
- * Version:	$Id: filters.c,v 1.36.4.1 2006/03/15 15:37:54 nbk Exp $
+ * Version:	$Id: filters.c,v 1.36.4.3 2006/05/03 17:35:02 aland Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2003  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: filters.c,v 1.36.4.1 2006/03/15 15:37:54 nbk Exp $";
+static const char rcsid[] = "$Id: filters.c,v 1.36.4.3 2006/05/03 17:35:02 aland Exp $";
 
 #include <string.h>
 #include <ctype.h>
@@ -1049,11 +1049,18 @@ ascend_parse_filter(VALUE_PAIR *pair)
 	ascend_filter_t filter;
 
 	rcode = -1;
+	
+	/*
+	 *	Rather than printing specific error messages, we create
+	 *	a general one here, which won't be used if the function
+	 *	returns OK.
+	 */
+	librad_log("Text is not in proper format");
 
 	/*
 	 *	Tokenize the input string in the VP.
 	 *
-	 *	Once the filter is *completelty* parsed, then we will
+	 *	Once the filter is *completely* parsed, then we will
 	 *	over-write it with the final binary filter.
 	 */
 	argc = str2argv(pair->strvalue, argv, 32);
@@ -1207,9 +1214,11 @@ void print_abinary(VALUE_PAIR *vp, u_char *buffer, int len)
   if (vp->length > SIZEOF_RADFILTER) {
     strcpy(p, "0x");
     p += 2;
+    len -= 2;
     for (i = 0; i < vp->length; i++) {
-      sprintf(p, " %02x", vp->strvalue[i]);
-      p += 3;
+      snprintf(p, len, "%02x", vp->strvalue[i]);
+      p += 2;
+      len -= 2;
     }
     return;
   }
