@@ -1,7 +1,7 @@
 /*
  * radius.c	Functions to send/receive radius packets.
  *
- * Version:	$Id: radius.c,v 1.125.2.5.2.5 2006/03/15 15:37:57 nbk Exp $
+ * Version:	$Id: radius.c,v 1.125.2.5.2.7 2006/05/16 18:26:06 aland Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000-2003  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: radius.c,v 1.125.2.5.2.5 2006/03/15 15:37:57 nbk Exp $";
+static const char rcsid[] = "$Id: radius.c,v 1.125.2.5.2.7 2006/05/16 18:26:06 aland Exp $";
 
 #include	"autoconf.h"
 #include	"md5.h"
@@ -1356,7 +1356,7 @@ RADIUS_PACKET *rad_recv(int fd)
 /*
  *	Verify the signature of a packet.
  */
-static int rad_verify(RADIUS_PACKET *packet, RADIUS_PACKET *original,
+int rad_verify(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 	       const char *secret)
 {
 	uint8_t			*ptr;
@@ -1594,6 +1594,7 @@ static VALUE_PAIR *rad_attr2vp(const RADIUS_PACKET *packet, const RADIUS_PACKET
 	switch (vp->type) {
 	case PW_TYPE_STRING:
 	case PW_TYPE_OCTETS:
+	case PW_TYPE_ABINARY:
 		/* nothing more to do */
 		break;
 
@@ -1715,8 +1716,6 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 	int			vsa_tlen, vsa_llen;
 	DICT_VENDOR		*dv = NULL;
 
-	if (rad_verify(packet, original, secret) < 0) return -1;
-
 	/*
 	 *	Extract attribute-value pairs
 	 */
