@@ -1,7 +1,7 @@
 /*
  * rbtree.c	Red-black balanced binary trees.
  *
- * Version:	$Id: rbtree.c,v 1.10.4.1 2005/11/30 22:40:19 aland Exp $
+ * Version:	$Id: rbtree.c,v 1.10.4.2 2006/03/15 15:37:57 nbk Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -15,12 +15,12 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  *  Copyright 2004  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: rbtree.c,v 1.10.4.1 2005/11/30 22:40:19 aland Exp $";
+static const char rcsid[] = "$Id: rbtree.c,v 1.10.4.2 2006/03/15 15:37:57 nbk Exp $";
 
 #include "autoconf.h"
 
