@@ -1,7 +1,7 @@
 /*
  * valuepair.c	Functions to handle VALUE_PAIRs
  *
- * Version:	$Id: valuepair.c,v 1.82.2.1.2.1 2006/03/15 15:37:58 nbk Exp $
+ * Version:	$Id: valuepair.c,v 1.82.2.1.2.3 2006/05/03 17:40:58 aland Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: valuepair.c,v 1.82.2.1.2.1 2006/03/15 15:37:58 nbk Exp $";
+static const char rcsid[] = "$Id: valuepair.c,v 1.82.2.1.2.3 2006/05/03 17:40:58 aland Exp $";
 
 #include	"autoconf.h"
 
@@ -734,26 +734,34 @@ VALUE_PAIR *pairparsevalue(VALUE_PAIR *vp, const char *value)
 			break;
 		case PW_TYPE_ABINARY:
 #ifdef ASCEND_BINARY
+			if (strncasecmp(value, "0x", 2) == 0) {
+				vp->type = PW_TYPE_OCTETS;
+				goto do_octets;
+			}			
+
 			/*
 			 *	Special case to convert filter to binary
 			 */
 			strNcpy(vp->strvalue, value, sizeof(vp->strvalue));
 		  	if (ascend_parse_filter(vp) < 0 ) {
+			  fprintf(stderr, "FUCK %s\n", value);
 				librad_log("failed to parse Ascend binary attribute: %s",
 					   librad_errstr);
 				return NULL;
 			}
 			break;
+
 			/*
 			 *	If Ascend binary is NOT defined,
 			 *	then fall through to raw octets, so that
 			 *	the user can at least make them by hand...
 			 */
+	do_octets:
 #endif
 			/* raw octets: 0x01020304... */
 		case PW_TYPE_OCTETS:
 			if (strncasecmp(value, "0x", 2) == 0) {
-				u_char *us;
+				uint8_t *us;
 				cp = value + 2;
 				us = vp->strvalue;
 				vp->length = 0;
@@ -1254,6 +1262,14 @@ VALUE_PAIR *pairread(char **ptr, LRAD_TOKEN *eol)
 		break;
 	}
 
+	/*
+	 *      If we didn't make a pair, return an error.
+	 */
+	if (!vp) {
+		*eol = T_INVALID;
+		return NULL;
+	}
+
 	return vp;
 }
 
