@@ -1,7 +1,7 @@
 /*
  * auth.c	User authentication.
  *
- * Version:	$Id: auth.c,v 1.136.2.4 2005/08/25 00:10:28 aland Exp $
+ * Version:	$Id: auth.c,v 1.136.2.5 2005/10/31 17:59:21 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  */
 
-static const char rcsid[] = "$Id: auth.c,v 1.136.2.4 2005/08/25 00:10:28 aland Exp $";
+static const char rcsid[] = "$Id: auth.c,v 1.136.2.5 2005/10/31 17:59:21 nbk Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -373,12 +373,13 @@ int rad_check_password(REQUEST *request)
 				 *	is the same as an explicit REJECT!
 				 */
 				case RLM_MODULE_FAIL:
-				case RLM_MODULE_REJECT:
-				case RLM_MODULE_USERLOCK:
 				case RLM_MODULE_INVALID:
-				case RLM_MODULE_NOTFOUND:
 				case RLM_MODULE_NOOP:
+				case RLM_MODULE_NOTFOUND:
+				case RLM_MODULE_REJECT:
 				case RLM_MODULE_UPDATED:
+				case RLM_MODULE_USERLOCK:
+				default:
 					result = -1;
 					break;
 				case RLM_MODULE_OK:
@@ -403,40 +404,45 @@ int rad_postauth(REQUEST *request)
 {
 	int	result;
 	int	postauth_type = 0;
-	VALUE_PAIR	*postauth_type_item = NULL;
+	VALUE_PAIR *vp;
 
 	/*
 	 *	Do post-authentication calls. ignoring the return code.
 	 */
-	postauth_type_item = pairfind(request->config_items, PW_POST_AUTH_TYPE);
-	if (postauth_type_item)
-		postauth_type = postauth_type_item->lvalue;
+	vp = pairfind(request->config_items, PW_POST_AUTH_TYPE);
+	if (vp) {
+		DEBUG2("  Found Post-Auth-Type %s", vp->strvalue);
+		postauth_type = vp->lvalue;
+	}
 	result = module_post_auth(postauth_type, request);
 	switch (result) {
-	default:
-	  break;
-
-	  /*
-	   *	The module failed, or said to reject the user: Do so.
-	   */
-	case RLM_MODULE_FAIL:
-	case RLM_MODULE_REJECT:
-	case RLM_MODULE_USERLOCK:
-	case RLM_MODULE_INVALID:
-	  request->reply->code = PW_AUTHENTICATION_REJECT;
-	  result = RLM_MODULE_REJECT;
-	  break;
-
-	  /*
-	   *	The module had a number of OK return codes.
-	   */
-	case RLM_MODULE_NOTFOUND:
-	case RLM_MODULE_NOOP:
-	case RLM_MODULE_UPDATED:
-	case RLM_MODULE_OK:
-	case RLM_MODULE_HANDLED:
-	  result = RLM_MODULE_OK;
-	  break;
+		/*
+		 *	The module failed, or said to reject the user: Do so.
+		 */
+		case RLM_MODULE_FAIL:
+		case RLM_MODULE_INVALID:
+		case RLM_MODULE_REJECT:
+		case RLM_MODULE_USERLOCK:
+		default:
+			request->reply->code = PW_AUTHENTICATION_REJECT;
+			result = RLM_MODULE_REJECT;
+			break;
+		/*
+		 *	The module handled the request, cancel the reply.
+		 */
+		case RLM_MODULE_HANDLED:
+			/* FIXME */
+			result = RLM_MODULE_OK;
+			break;
+		/*
+		 *	The module had a number of OK return codes.
+		 */
+		case RLM_MODULE_NOOP:
+		case RLM_MODULE_NOTFOUND:
+		case RLM_MODULE_OK:
+		case RLM_MODULE_UPDATED:
+			result = RLM_MODULE_OK;
+			break;
 	}
 	return result;
 }
@@ -494,51 +500,42 @@ int rad_authenticate(REQUEST *request)
 	password = "";
 
 	/*
-	 *	If this request got proxied to another server,
-	 *	AND it was an authentication request, then we need
-	 *	to add an initial Auth-Type: Auth-Accept for success,
-	 *	Auth-Reject for fail. We also need to add the reply
-	 *	pairs from the server to the initial reply.
-	 *
-	 *	Huh?  If the request wasn't an authentication request,
-	 *	WTF are we doing here?
+	 *	If this request got proxied to another server, we need
+	 *	to check whether it authenticated the request or not.
 	 */
-	if ((request->proxy_reply) &&
-	    (request->packet->code == PW_AUTHENTICATION_REQUEST)) {
-		tmp = paircreate(PW_AUTH_TYPE, PW_TYPE_INTEGER);
-		if (tmp == NULL) {
-			radlog(L_ERR|L_CONS, "no memory");
-			exit(1);
-		}
-
+	if (request->proxy_reply) {
+		switch (request->proxy_reply->code) {
 		/*
-		 *	Challenges are punted back to the NAS
-		 *	without any further processing.
+		 *	Reply of ACCEPT means accept, thus set Auth-Type
+		 *	accordingly.
 		 */
-		if (request->proxy_reply->code == PW_ACCESS_CHALLENGE) {
-			request->reply->code = PW_ACCESS_CHALLENGE;
-			return RLM_MODULE_HANDLED;
-		}
-
-		/*
-		 *	Reply of ACCEPT means accept, ALL other
-		 *	replies mean reject.  This is fail-safe.
-		 */
-		if (request->proxy_reply->code == PW_AUTHENTICATION_ACK)
+		case PW_AUTHENTICATION_ACK:
+			tmp = paircreate(PW_AUTH_TYPE, PW_TYPE_INTEGER);
+			if (tmp == NULL) {
+				radlog(L_ERR|L_CONS, "Not enough memory");
+				exit(1);
+			}
 			tmp->lvalue = PW_AUTHTYPE_ACCEPT;
-		else
-			tmp->lvalue = PW_AUTHTYPE_REJECT;
-		pairadd(&request->config_items, tmp);
-
+			pairadd(&request->config_items, tmp);
+			break;
 		/*
-		 *	If it's an Access-Reject, then do NOT do any
-		 *	authorization or authentication.  They're being
-		 *	rejected, so we minimize the amount of work
+		 *	Challenges are punted back to the NAS without any
+		 *	further processing.
+		 */
+		case PW_ACCESS_CHALLENGE:
+			request->reply->code = PW_ACCESS_CHALLENGE;
+			return RLM_MODULE_OK;
+		/*
+		 *	ALL other replies mean reject. (this is fail-safe)
+		 *
+		 *	Do NOT do any authorization or authentication. They
+		 *	are being rejected, so we minimize the amount of work
 		 *	done by the server, by rejecting them here.
 		 */
-		if ((request->proxy_reply->code != PW_AUTHENTICATION_ACK) &&
-		    (request->proxy_reply->code != PW_ACCESS_CHALLENGE)) {
-			rad_authlog("Login incorrect (Home Server says so)", request, 0);
+		case PW_AUTHENTICATION_REJECT:
+		default:
+			rad_authlog("Login incorrect (Home Server says so)",
+				    request, 0);
 			request->reply->code = PW_AUTHENTICATION_REJECT;
 			rad_postauth_reject(request);
 			return RLM_MODULE_REJECT;
@@ -589,15 +586,23 @@ int rad_authenticate(REQUEST *request)
 	 *	Get the user's authorization information from the database
 	 */
 autz_redo:
-	r = module_authorize(autz_type, request);
-	if (r != RLM_MODULE_NOTFOUND &&
-	    r != RLM_MODULE_NOOP &&
-	    r != RLM_MODULE_OK &&
-	    r != RLM_MODULE_UPDATED) {
-		if (r != RLM_MODULE_FAIL && r != RLM_MODULE_HANDLED) {
+	result = module_authorize(autz_type, request);
+	switch (result) {
+		case RLM_MODULE_NOOP:
+		case RLM_MODULE_NOTFOUND:
+		case RLM_MODULE_OK:
+		case RLM_MODULE_UPDATED:
+			break;
+		case RLM_MODULE_FAIL:
+		case RLM_MODULE_HANDLED:
+			return result;
+		case RLM_MODULE_INVALID:
+		case RLM_MODULE_REJECT:
+		case RLM_MODULE_USERLOCK:
+		default:
 			if ((module_msg = pairfind(request->packet->vps,
-					PW_MODULE_FAILURE_MESSAGE)) != NULL){
-				char msg[MAX_STRING_LEN+16];
+					PW_MODULE_FAILURE_MESSAGE)) != NULL) {
+				char msg[MAX_STRING_LEN + 16];
 				snprintf(msg, sizeof(msg), "Invalid user (%s)",
 					 module_msg->strvalue);
 				rad_authlog(msg,request,0);
@@ -605,14 +610,13 @@ autz_redo:
 				rad_authlog("Invalid user", request, 0);
 			}
 			request->reply->code = PW_AUTHENTICATION_REJECT;
-		}
-		return r;
+			return result;
 	}
-	if (!autz_retry){
-		VALUE_PAIR	*autz_type_item = NULL;
-		autz_type_item = pairfind(request->config_items, PW_AUTZ_TYPE);
-		if (autz_type_item){
-			autz_type = autz_type_item->lvalue;
+	if (!autz_retry) {
+		tmp = pairfind(request->config_items, PW_AUTZ_TYPE);
+		if (tmp) {
+			DEBUG2("  Found Autz-Type %s", tmp->strvalue);
+			autz_type = tmp->lvalue;
 			autz_retry = 1;
 			goto autz_redo;
 		}
@@ -701,19 +705,20 @@ autz_redo:
 
 	if (result >= 0 &&
 	    (check_item = pairfind(request->config_items, PW_SIMULTANEOUS_USE)) != NULL) {
-		VALUE_PAIR	*session_type;
-		int		sess_type = 0;
+		int session_type = 0;
 
-		session_type = pairfind(request->config_items, PW_SESSION_TYPE);
-		if (session_type)
-			sess_type = session_type->lvalue;
+		tmp = pairfind(request->config_items, PW_SESSION_TYPE);
+		if (tmp) {
+			DEBUG2("  Found Session-Type %s", tmp->strvalue);
+			session_type = tmp->lvalue;
+		}
 
 		/*
 		 *	User authenticated O.K. Now we have to check
 		 *	for the Simultaneous-Use parameter.
 		 */
 		if (namepair &&
-		    (r = module_checksimul(sess_type,request, check_item->lvalue)) != 0) {
+		    (r = module_checksimul(session_type, request, check_item->lvalue)) != 0) {
 			char mpp_ok = 0;
 
 			if (r == 2){
