@@ -1,7 +1,7 @@
 /*
  * exec.c	Execute external programs.
  *
- * Version:	$Id: exec.c,v 1.42.2.1 2005/08/26 19:17:45 aland Exp $
+ * Version:	$Id: exec.c,v 1.42.2.1.2.1 2006/03/24 17:54:57 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  * Copyright 2000  Michael J. Hartwick <hartwick@hartwick.com>
  */
-static const char rcsid[] = "$Id: exec.c,v 1.42.2.1 2005/08/26 19:17:45 aland Exp $";
+static const char rcsid[] = "$Id: exec.c,v 1.42.2.1.2.1 2006/03/24 17:54:57 aland Exp $";
 
 #include "autoconf.h"
 
@@ -30,6 +30,7 @@ static const char rcsid[] = "$Id: exec.c,v 1.42.2.1 2005/08/26 19:17:45 aland Ex
 #include <string.h>
 #include <fcntl.h>
 #include <ctype.h>
+#include <unistd.h>
 #include <signal.h>
 
 #ifdef HAVE_SYS_WAIT_H
@@ -128,7 +129,7 @@ int radius_exec_program(const char *cmd, REQUEST *request,
 
 	if ((pid = rad_fork(exec_wait)) == 0) {
 #define MAX_ENVP 1024
-		int i, devnull;
+		int devnull;
 		char *envp[MAX_ENVP];
 		int envlen;
 		char buffer[1024];
@@ -198,9 +199,7 @@ int radius_exec_program(const char *cmd, REQUEST *request,
 		 *	want to leave dangling FD's for the child process
 		 *	to play funky games with, so we close them.
 		 */
-		for (i = 3; i < 256; i++) {
-			close(i);
-		}
+		closefrom(3);
 
 		/*
 		 *	Set up the environment variables.
