@@ -1,7 +1,7 @@
 /*
  * log.c	Logging module.
  *
- * Version:	$Id: log.c,v 1.41 2004/02/26 19:04:23 aland Exp $
+ * Version:	$Id: log.c,v 1.41.2.1 2005/09/01 16:07:30 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * Copyright 2001  Chad Miller <cmiller@surfsouth.com>
  */
 
-static const char rcsid[] = "$Id: log.c,v 1.41 2004/02/26 19:04:23 aland Exp $";
+static const char rcsid[] = "$Id: log.c,v 1.41.2.1 2005/09/01 16:07:30 nbk Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -129,14 +129,7 @@ int vradlog(int lvl, const char *fmt, va_list ap)
 		len = strlen(buffer);
 	}
 
-#ifdef HAVE_VSNPRINTF
-	vsnprintf(buffer + len, sizeof(buffer) - len -1, fmt, ap);
-#else
-	vsprintf(buffer + len, fmt, ap);
-	if (strlen(buffer) >= sizeof(buffer) - 1)
-		/* What can we do? */
-		_exit(42);
-#endif
+	vsnprintf(buffer + len, sizeof(buffer) - len - 1, fmt, ap);
 
 	/*
 	 *	Filter out characters not in Latin-1.
