@@ -1,7 +1,7 @@
 /*
  * mainconf.c	Handle the server's configuration.
  *
- * Version:	$Id: mainconfig.c,v 1.36.2.6.2.1 2006/02/07 09:43:27 nbk Exp $
+ * Version:	$Id: mainconfig.c,v 1.36.2.6.2.2 2006/04/18 17:26:26 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -49,6 +49,9 @@
 #include <grp.h>
 #include <pwd.h>
 
+#ifdef HAVE_SYS_PRCTL_H
+#include <sys/prctl.h>
+#endif
 
 #ifdef WITH_UDPFROMTO
 #include "udpfromto.h"
@@ -1415,6 +1418,17 @@ int read_mainconfig(int reload)
 	}
 	switch_users();
 
+#ifdef HAVE_SYS_PRCTL_H
+#ifdef HAVE_PR_SET_DUMPABLE
+	if (mainconfig.allow_core_dumps) {
+		if (prctl(PR_SET_DUMPABLE, 1) < 0) {
+			radlog(L_ERR|L_CONS,"Cannot enable core dumps: prctl(PR_SET_DUMPABLE) failed: '%s'",
+			       strerror(errno));
+		}
+	}
+#endif
+#endif
+
 	/*
 	 *	Sanity check the configuration for internal
 	 *	consistency.
