@@ -1,7 +1,7 @@
 /*
  * modules.c	Radius module support.
  *
- * Version:	$Id: modules.c,v 1.86.2.1.2.2 2006/01/09 23:06:26 aland Exp $
+ * Version:	$Id: modules.c,v 1.86.2.1.2.4 2006/04/07 17:53:25 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Alan Curry <pacman@world.std.com>
  */
 
-static const char rcsid[] = "$Id: modules.c,v 1.86.2.1.2.2 2006/01/09 23:06:26 aland Exp $";
+static const char rcsid[] = "$Id: modules.c,v 1.86.2.1.2.4 2006/04/07 17:53:25 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -470,7 +470,7 @@ static int indexed_modcall(int comp, int idx, REQUEST *request)
 }
 
 /* Load a flat module list, as found inside an authtype{} block */
-static void load_subcomponent_section(CONF_SECTION *cs, int comp,
+static int load_subcomponent_section(CONF_SECTION *cs, int comp,
 				      const char *filename)
 {
 	int idx;
@@ -482,7 +482,7 @@ static void load_subcomponent_section(CONF_SECTION *cs, int comp,
 
 	ml = compile_modgroup(comp, cs, filename);
 	if (!ml) {
-		return; /* FIXME: pull full fix from CVS head */
+		return 0;
 	}
 
 	/* We must assign a numeric index to this subcomponent. For
@@ -522,10 +522,12 @@ static void load_subcomponent_section(CONF_SECTION *cs, int comp,
 				filename, cf_section_lineno(cs),
 				subcomponent_names[comp], cf_section_name2(cs));
 		modcallable_free(&ml);
-		return;
+		return 1;
 	}
 
 	subcomp->modulelist = ml;
+
+	return 1;
 }
 
 static int load_component_section(CONF_SECTION *cs, int comp,
@@ -541,16 +543,21 @@ static int load_component_section(CONF_SECTION *cs, int comp,
 	for (modref=cf_item_find_next(cs, NULL);
 			modref != NULL;
 			modref=cf_item_find_next(cs, modref)) {
+		CONF_PAIR *cp = NULL;
+		CONF_SECTION *scs = NULL;
 
 		if (cf_item_is_section(modref)) {
 			const char *sec_name;
-			CONF_SECTION *scs;
 			scs = cf_itemtosection(modref);
 
 			sec_name = cf_section_name1(scs);
+
 			if (strcmp(sec_name,
 				   subcomponent_names[comp]) == 0) {
-				load_subcomponent_section(scs, comp, filename);
+				if (!load_subcomponent_section(scs, comp,
+							       filename)) {
+					return -1; /* FIXME: memleak? */
+				}
 				continue;
 			}
 
@@ -559,11 +566,14 @@ static int load_component_section(CONF_SECTION *cs, int comp,
 			 */
 			if (strcmp(sec_name,
 				   old_subcomponent_names[comp]) == 0) {
-				load_subcomponent_section(scs, comp, filename);
+				if (!load_subcomponent_section(scs, comp,
+							       filename)) {
+					return -1; /* FIXME: memleak? */
+				}
 				continue;
 			}
+			cp = NULL;
 		} else {
-			CONF_PAIR *cp;
 			cp = cf_itemtopair(modref);
 		}
 
@@ -576,19 +586,32 @@ static int load_component_section(CONF_SECTION *cs, int comp,
                         return -1;
                 }
 
-
 		if (comp == RLM_COMPONENT_AUTH) {
 			DICT_VALUE *dval;
+			const char *modrefname = NULL;
 
-			dval = dict_valbyname(PW_AUTH_TYPE, modname);
+			if (cp) {
+				modrefname = cf_pair_attr(cp);
+			} else {
+				modrefname = cf_section_name2(scs);
+				if (!modrefname) {
+					radlog(L_ERR|L_CONS,
+					       "%s[%d] Failed to parse %s sub-section.\n",
+					       filename, cf_section_lineno(scs),
+					       cf_section_name1(scs));
+					return -1;
+				}
+			}
+			
+			dval = dict_valbyname(PW_AUTH_TYPE, modrefname);
 			if (!dval) {
 				/*
 				 *	It's a section, but nothing we
 				 *	recognize.  Die!
 				 */
 				radlog(L_ERR|L_CONS, "%s[%d] Unknown Auth-Type \"%s\" in %s section.",
-				       filename, cf_section_lineno(cs),
-				       modname, component_names[comp]);
+				       filename, cf_section_lineno(scs),
+				       modrefname, component_names[comp]);
 				return -1;
 			}
 			idx = dval->value;
