@@ -2,7 +2,7 @@
  * nas.c	Functions to do with a NASLIST. This is here because
  *		radzap needs it as well.
  *
- * Version:     $Id: nas.c,v 1.20 2003/06/15 14:09:33 hartwick Exp $
+ * Version:     $Id: nas.c,v 1.22 2004/02/26 19:04:23 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
 
-static const char rcsid[] = "$Id: nas.c,v 1.20 2003/06/15 14:09:33 hartwick Exp $";
+static const char rcsid[] = "$Id: nas.c,v 1.22 2004/02/26 19:04:23 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -89,7 +89,8 @@ int read_naslist_file(char *file)
 		p = buffer;
 		if (!getword(&p, hostnm, sizeof(hostnm)) ||
 		    !getword(&p, shortnm, sizeof(shortnm))) {
-			radlog(L_ERR, "%s[%d]: unexpected end of line", file, lineno);
+			radlog(L_ERR, "%s[%d]: unexpected end of line",
+			       file, lineno);
 			continue;
 		}
 		(void)getword(&p, nastype, sizeof(nastype));
@@ -99,23 +100,26 @@ int read_naslist_file(char *file)
 		 */
 		if (strlen(hostnm) >= sizeof(nas->longname)) {
 			radlog(L_ERR, "%s[%d]: host name of length %d is greater than the allowed maximum of %d.",
-					file, lineno,
-					strlen(hostnm), sizeof(nas->longname) - 1);
+			       file, lineno,
+			       (int) strlen(hostnm),
+			       (int) sizeof(nas->longname) - 1);
 			return -1;
 		}
 		if (strlen(shortnm) > sizeof(nas->shortname)) {
 			radlog(L_ERR, "%s[%d]: short name of length %d is greater than the allowed maximum of %d.",
-					file, lineno,
-					strlen(shortnm), sizeof(nas->shortname) - 1);
+			       file, lineno,
+			       (int) strlen(shortnm),
+			       (int) sizeof(nas->shortname) - 1);
 			return -1;
 		}
 		if (strlen(nastype) >= sizeof(nas->nastype)) {
 			radlog(L_ERR, "%s[%d]: NAS type of length %d is greater than the allowed maximum of %d.",
-					file, lineno,
-					strlen(nastype), sizeof(nas->nastype) - 1);
+			       file, lineno,
+			       (int) strlen(nastype),
+			       (int) sizeof(nas->nastype) - 1);
 			return -1;
 		}
-		
+
 		/*
 		 *	It should be OK now, let's create the buffer.
 		 */
@@ -223,7 +227,7 @@ const char *nas_name2(RADIUS_PACKET *packet)
 }
 
 /*
- *	Find the name of a nas (prefer short name) based on ipaddr, 
+ *	Find the name of a nas (prefer short name) based on ipaddr,
  *	store in passed buffer.  If NAS is unknown, return dotted quad.
  */
 char * nas_name3(char *buf, size_t buflen, uint32_t ipaddr)
