@@ -1,7 +1,7 @@
 /*
  * radiusd.c	Main loop of the radius server.
  *
- * Version:	$Id: radiusd.c,v 1.321.2.2.2.2 2005/12/28 01:18:00 aland Exp $
+ * Version:	$Id: radiusd.c,v 1.321.2.2.2.3 2006/05/16 18:26:07 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 
 /* don't look here for the version, run radiusd -v or look in version.c */
 static const char rcsid[] =
-"$Id: radiusd.c,v 1.321.2.2.2.2 2005/12/28 01:18:00 aland Exp $";
+"$Id: radiusd.c,v 1.321.2.2.2.3 2006/05/16 18:26:07 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -1560,10 +1560,21 @@ int rad_respond(REQUEST *request, RAD_REQUEST_FUNP fun)
 	 *  wire) have ->data==NULL (data is the wire
 	 *  format) and don't need to be "decoded"
 	 */
-	if (packet->data && rad_decode(packet, original, secret) != 0) {
-		radlog(L_ERR, "%s", librad_errstr);
-		request_reject(request);
-		goto finished_request;
+	if (packet->data) {
+		if (rad_verify(packet, original, secret) < 0) {
+			radlog(L_ERR, "%s Dropping packet without response.", librad_errstr);
+			/* Since accounting packets get this set in
+			 * request_reject but no response is sent...
+			 */
+			request->options |= RAD_REQUEST_OPTION_REJECTED;
+			goto finished_request;
+		}
+
+		if (rad_decode(packet, original, secret) < 0) {
+			radlog(L_ERR, "%s", librad_errstr);
+			request_reject(request);
+			goto finished_request;
+		}
 	}
 
 	/*
