@@ -1,7 +1,7 @@
 /*
  * threads.c	request threading support
  *
- * Version:	$Id: threads.c,v 1.77.2.6 2005/08/16 21:29:55 aland Exp $
+ * Version:	$Id: threads.c,v 1.77.2.7 2005/10/17 18:38:07 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@
 #include "conffile.h"
 
 static const char rcsid[] =
-"$Id: threads.c,v 1.77.2.6 2005/08/16 21:29:55 aland Exp $";
+"$Id: threads.c,v 1.77.2.7 2005/10/17 18:38:07 aland Exp $";
 
 #define SEMAPHORE_LOCKED	(0)
 #define SEMAPHORE_UNLOCKED	(1)
@@ -219,7 +219,7 @@ static void reap_children(void)
  *
  *	This function should never fail.
  */
-static void request_enqueue(REQUEST *request, RAD_REQUEST_FUNP fun)
+static int request_enqueue(REQUEST *request, RAD_REQUEST_FUNP fun)
 {
 	int num_entries;
 
@@ -260,7 +260,7 @@ static void request_enqueue(REQUEST *request, RAD_REQUEST_FUNP fun)
 			 */
 			radlog(L_ERR|L_CONS, "!!! ERROR !!! The server is blocked: discarding new request %d", request->number);
 			request->finished = TRUE;
-			return;
+			return 0;
 		}
 
 		/*
@@ -311,7 +311,7 @@ static void request_enqueue(REQUEST *request, RAD_REQUEST_FUNP fun)
 
 	sem_post(&thread_pool.semaphore);
 
-	return;
+	return 1;
 }
 
 /*
@@ -796,6 +796,11 @@ int thread_pool_init(void)
  */
 int thread_pool_addrequest(REQUEST *request, RAD_REQUEST_FUNP fun)
 {
+	/*
+	 *	Add the new request to the queue.
+	 */
+	if (!request_enqueue(request, fun)) return 0;
+
 	/*
 	 *	If the thread pool is busy handling requests, then
 	 *	try to spawn another one.
@@ -805,15 +810,10 @@ int thread_pool_addrequest(REQUEST *request, RAD_REQUEST_FUNP fun)
 			radlog(L_INFO,
 			       "The maximum number of threads (%d) are active, cannot spawn new thread to handle request",
 			       thread_pool.max_threads);
-			return 0;
+			return 1;
 		}
 	}
 
-	/*
-	 *	Add the new request to the queue.
-	 */
-	request_enqueue(request, fun);
-
 	return 1;
 }
 
