@@ -2,7 +2,7 @@
  * xlat.c	Translate strings.  This is the first version of xlat
  * 		incorporated to RADIUS
  *
- * Version:	$Id: xlat.c,v 1.72.2.7 2005/08/29 16:19:41 aland Exp $
+ * Version:	$Id: xlat.c,v 1.72.2.7.2.1 2005/12/08 12:47:56 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  */
 
 static const char rcsid[] =
-"$Id: xlat.c,v 1.72.2.7 2005/08/29 16:19:41 aland Exp $";
+"$Id: xlat.c,v 1.72.2.7.2.1 2005/12/08 12:47:56 nbk Exp $";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -141,7 +141,51 @@ static int xlat_packet(void *instance, REQUEST *request,
 	 *	The "format" string is the attribute name.
 	 */
 	da = dict_attrbyname(fmt);
-	if (!da) return 0;
+	if (!da) {
+		int index;
+		const char *p = strchr(fmt, '[');
+		char buffer[256];
+
+		if (!p) return 0;
+		if (strlen(fmt) > sizeof(buffer)) return 0;
+
+		strNcpy(buffer, fmt, p - fmt + 1);
+
+		index = atoi(p + 1);
+
+		/*
+		 *	Check the format of the index before looking
+		 *	the attribute up in the dictionary, because
+		 *	it's a cheap check.
+		 */
+		p += 1 + strspn(p + 1, "0123456789");
+		if (*p != ']') {
+			DEBUG2("xlat: Invalid array reference in string at %s %s",
+			       fmt, p);
+			return 0;
+		}
+
+		da = dict_attrbyname(buffer);
+		if (!da) return 0;
+
+
+		/*
+		 *	Find the N'th value.
+		 */
+		for (vp = pairfind(vps, da->attr);
+		     vp != NULL;
+		     vp = pairfind(vp->next, da->attr)) {
+			if (index == 0) break;
+			index--;
+		}
+
+		/*
+		 *	Non-existent array reference.
+		 */
+		if (!vp) return 0;
+
+		return valuepair2str(out, outlen, vp, da->type, func);
+	}
 
 	vp = pairfind(vps, da->attr);
 	if (!vp) {
