@@ -3,7 +3,7 @@
  *                      before sending reply to the NAS/Server that sent
  *                      it to us.
  *
- * Version:      $Id: rlm_attr_filter.c,v 1.19 2004/05/15 14:51:26 mgriego Exp $
+ * Version:      $Id: rlm_attr_filter.c,v 1.19.2.1 2005/08/11 21:06:38 aland Exp $
  *
  *   This program is is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License, version 2 if the
@@ -41,7 +41,7 @@
 #include	"radiusd.h"
 #include	"modules.h"
 
-static const char rcsid[] = "$Id: rlm_attr_filter.c,v 1.19 2004/05/15 14:51:26 mgriego Exp $";
+static const char rcsid[] = "$Id: rlm_attr_filter.c,v 1.19.2.1 2005/08/11 21:06:38 aland Exp $";
 
 struct attr_filter_instance {
         /* autz */
@@ -114,7 +114,7 @@ static int check_pair(VALUE_PAIR *check_item, VALUE_PAIR *reply_item,
 		    break;
 #ifdef HAVE_REGEX_H
 		case T_OP_REG_EQ:
-		    regcomp(&reg, (char *)check_item->strvalue, 0);
+		    regcomp(&reg, (char *)check_item->strvalue, REG_EXTENDED);
 		    comp = regexec(&reg, (char *)reply_item->strvalue,
 				      0, NULL, 0);
 		    regfree(&reg);
@@ -126,7 +126,7 @@ static int check_pair(VALUE_PAIR *check_item, VALUE_PAIR *reply_item,
 		    break;
 
 		case T_OP_REG_NE:
-		    regcomp(&reg, (char *)check_item->strvalue, 0);
+		    regcomp(&reg, (char *)check_item->strvalue, REG_EXTENDED);
 		    comp = regexec(&reg, (char *)reply_item->strvalue,
 				      0, NULL, 0);
 		    regfree(&reg);
