@@ -1,7 +1,7 @@
 /*
  * rlm_chap.c
  *
- * Version:  $Id: rlm_digest.c,v 1.5.4.4 2006/03/06 19:02:58 aland Exp $
+ * Version:  $Id: rlm_digest.c,v 1.5.4.5 2006/04/28 23:44:31 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include "modules.h"
 #include "conffile.h"
 
-static const char rcsid[] = "$Id: rlm_digest.c,v 1.5.4.4 2006/03/06 19:02:58 aland Exp $";
+static const char rcsid[] = "$Id: rlm_digest.c,v 1.5.4.5 2006/04/28 23:44:31 aland Exp $";
 
 static int digest_authorize(void *instance, REQUEST *request)
 {
@@ -106,7 +106,7 @@ static int digest_authenticate(void *instance, REQUEST *request)
 		passwd = pairfind(request->config_items, PW_PASSWORD);
 	}
 	if (!passwd) {
-		radlog(L_AUTH, "rlm_digest: Configuration item \"User-Password\" or MD5-Password is required for authentication.");
+		radlog(L_AUTH, "rlm_digest: Configuration item \"User-Password\" or Digest-HA1 is required for authentication.");
 		return RLM_MODULE_INVALID;
 	}
 
