@@ -1,7 +1,7 @@
 /*
  * mem.c  Memory allocation, deallocation stuff.
  *
- * Version:     $Id: mem.c,v 1.14.4.1 2006/02/06 16:23:51 nbk Exp $
+ * Version:     $Id: mem.c,v 1.14.4.2 2006/05/09 20:59:23 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #include <stdio.h>
 #include "rlm_eap.h"
 
-static const char rcsid[] = "$Id: mem.c,v 1.14.4.1 2006/02/06 16:23:51 nbk Exp $";
+static const char rcsid[] = "$Id: mem.c,v 1.14.4.2 2006/05/09 20:59:23 aland Exp $";
 
 /*
  * Allocate a new EAP_PACKET
@@ -223,8 +223,11 @@ int eaplist_add(rlm_eap_t *inst, EAP_HANDLER *handler)
 		if (prev) {
 			prev->next = handler;
 			handler->prev = prev;
+			handler->next = NULL;
+			inst->session_tail = handler;
 		} else {
 			inst->session_head = inst->session_tail = handler;
+			handler->next = handler->prev = NULL;
 		}
 	}
 
@@ -331,12 +334,12 @@ EAP_HANDLER *eaplist_find(rlm_eap_t *inst, REQUEST *request,
 			if (handler->prev) {
 				handler->prev->next = handler->next;
 			} else {
-				inst->session_head = NULL;
+				inst->session_head = handler->next;
 			}
 			if (handler->next) {
 				handler->next->prev = handler->prev;
 			} else {
-				inst->session_tail = NULL;
+				inst->session_tail = handler->prev;
 			}
 			handler->prev = handler->next = NULL;
 		}
