@@ -1,7 +1,7 @@
 /*
  * rlm_eap_tls.c  contains the interfaces that are called from eap
  *
- * Version:     $Id: rlm_eap_tls.c,v 1.21.4.2 2006/02/06 15:37:03 nbk Exp $
+ * Version:     $Id: rlm_eap_tls.c,v 1.21.4.8 2006/04/28 18:20:42 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,12 +22,13 @@
  */
 
 #include "autoconf.h"
-#include "eap_tls.h"
 
 #ifdef HAVE_OPENSSL_RAND_H
 #include <openssl/rand.h>
 #endif
 
+#include "rlm_eap_tls.h"
+
 static CONF_PARSER module_config[] = {
 	{ "rsa_key_exchange", PW_TYPE_BOOLEAN,
 	  offsetof(EAP_TLS_CONF, rsa_key), NULL, "no" },
@@ -63,6 +64,10 @@ static CONF_PARSER module_config[] = {
 	  offsetof(EAP_TLS_CONF, check_crl), NULL, "no"},
 	{ "check_cert_cn", PW_TYPE_STRING_PTR,
 	  offsetof(EAP_TLS_CONF, check_cert_cn), NULL, NULL},
+	{ "cipher_list", PW_TYPE_STRING_PTR,
+	  offsetof(EAP_TLS_CONF, cipher_list), NULL, NULL},
+	{ "check_cert_issuer", PW_TYPE_STRING_PTR,
+	  offsetof(EAP_TLS_CONF, check_cert_issuer), NULL, NULL},
 
  	{ NULL, -1, 0, NULL, NULL }           /* end the list */
 };
@@ -112,6 +117,153 @@ static int generate_eph_rsa_key(SSL_CTX *ctx)
 }
 
 
+/*
+ *	Before trusting a certificate, you must make sure that the
+ *	certificate is 'valid'. There are several steps that your
+ *	application can take in determining if a certificate is
+ *	valid. Commonly used steps are:
+ *
+ *	1.Verifying the certificate's signature, and verifying that
+ *	the certificate has been issued by a trusted Certificate
+ *	Authority.
+ *
+ *	2.Verifying that the certificate is valid for the present date
+ *	(i.e. it is being presented within its validity dates).
+ *
+ *	3.Verifying that the certificate has not been revoked by its
+ *	issuing Certificate Authority, by checking with respect to a
+ *	Certificate Revocation List (CRL).
+ *
+ *	4.Verifying that the credentials presented by the certificate
+ *	fulfill additional requirements specific to the application,
+ *	such as with respect to access control lists or with respect
+ *	to OCSP (Online Certificate Status Processing).
+ *
+ *	NOTE: This callback will be called multiple times based on the
+ *	depth of the root certificate chain
+ */
+static int cbtls_verify(int ok, X509_STORE_CTX *ctx)
+{
+	char subject[1024]; /* Used for the subject name */
+	char issuer[1024]; /* Used for the issuer name */
+	char common_name[1024];
+	char cn_str[1024];
+	EAP_HANDLER *handler = NULL;
+	X509 *client_cert;
+	SSL *ssl;
+	int err, depth;
+	EAP_TLS_CONF *conf;
+	int my_ok = ok;
+
+	client_cert = X509_STORE_CTX_get_current_cert(ctx);
+	err = X509_STORE_CTX_get_error(ctx);
+	depth = X509_STORE_CTX_get_error_depth(ctx);
+
+	if (!my_ok) {
+		radlog(L_ERR,"--> verify error:num=%d:%s\n",err,
+			X509_verify_cert_error_string(err));
+		return my_ok;
+	}
+
+	/*
+	 * Retrieve the pointer to the SSL of the connection currently treated
+	 * and the application specific data stored into the SSL object.
+	 */
+	ssl = X509_STORE_CTX_get_ex_data(ctx, SSL_get_ex_data_X509_STORE_CTX_idx());
+	handler = (EAP_HANDLER *)SSL_get_ex_data(ssl, 0);
+	conf = (EAP_TLS_CONF *)SSL_get_ex_data(ssl, 1);
+
+	/*
+	 *	Get the Subject & Issuer
+	 */
+	subject[0] = issuer[0] = '\0';
+	X509_NAME_oneline(X509_get_subject_name(client_cert), subject,
+			  sizeof(subject));
+	X509_NAME_oneline(X509_get_issuer_name(ctx->current_cert), issuer,
+			  sizeof(issuer));
+
+	subject[sizeof(subject) - 1] = '\0';
+	issuer[sizeof(issuer) - 1] = '\0';
+
+	/*
+	 *	Get the Common Name
+	 */
+	X509_NAME_get_text_by_NID(X509_get_subject_name(client_cert),
+				  NID_commonName, common_name, sizeof(common_name));
+	common_name[sizeof(common_name) - 1] = '\0';
+
+	switch (ctx->error) {
+
+	case X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT:
+		radlog(L_ERR, "issuer= %s\n", issuer);
+		break;
+	case X509_V_ERR_CERT_NOT_YET_VALID:
+	case X509_V_ERR_ERROR_IN_CERT_NOT_BEFORE_FIELD:
+		radlog(L_ERR, "notBefore=");
+#if 0
+		ASN1_TIME_print(bio_err, X509_get_notBefore(ctx->current_cert));
+#endif
+		break;
+	case X509_V_ERR_CERT_HAS_EXPIRED:
+	case X509_V_ERR_ERROR_IN_CERT_NOT_AFTER_FIELD:
+		radlog(L_ERR, "notAfter=");
+#if 0
+		ASN1_TIME_print(bio_err, X509_get_notAfter(ctx->current_cert));
+#endif
+		break;
+	}
+
+	/*
+	 *	If we're at the actual client cert, apply additional
+	 *	checks.
+	 */
+	if (depth == 0) {
+		/*
+		 *	If the conf tells us to, check cert issuer
+		 *	against the specified value and fail
+		 *	verification if they don't match.
+		 */
+		if (conf->check_cert_issuer && 
+		    (strcmp(issuer, conf->check_cert_issuer) != 0)) {
+			radlog(L_AUTH, "rlm_eap_tls: Certificate issuer (%s) does not match specified value (%s)!", issuer, conf->check_cert_issuer);
+ 			my_ok = 0;
+ 		}
+
+		/*
+		 *	If the conf tells us to, check the CN in the
+		 *	cert against xlat'ed value, but only if the
+		 *	previous checks passed.
+		 */
+		if (my_ok && conf->check_cert_cn) {
+			if (!radius_xlat(cn_str, sizeof(cn_str), conf->check_cert_cn, handler->request, NULL)) {
+				radlog(L_ERR, "rlm_eap_tls (%s): xlat failed.",
+				       conf->check_cert_cn);
+				/* if this fails, fail the verification */
+				my_ok = 0;
+			} else {
+				DEBUG2("    rlm_eap_tls: checking certificate CN (%s) with xlat'ed value (%s)", common_name, cn_str);
+				if (strcmp(cn_str, common_name) != 0) {
+					radlog(L_AUTH, "rlm_eap_tls: Certificate CN (%s) does not match specified value (%s)!", common_name, cn_str);
+					my_ok = 0;
+				}
+			}
+		} /* check_cert_cn */
+	} /* depth == 0 */
+
+	if (debug_flag > 0) {
+		radlog(L_INFO, "chain-depth=%d, ", depth);
+		radlog(L_INFO, "error=%d", err);
+
+		radlog(L_INFO, "--> User-Name = %s", handler->identity);
+		radlog(L_INFO, "--> BUF-Name = %s", common_name);
+		radlog(L_INFO, "--> subject = %s", subject);
+		radlog(L_INFO, "--> issuer  = %s", issuer);
+		radlog(L_INFO, "--> verify return:%d", my_ok);
+	}
+	return my_ok;
+}
+
+
 /*
  *	Create Global context SSL and use it in every new session
  *
@@ -124,7 +276,7 @@ static SSL_CTX *init_tls_ctx(EAP_TLS_CONF *conf)
 	SSL_METHOD *meth;
 	SSL_CTX *ctx;
 	X509_STORE *certstore;
-	int verify_mode = 0;
+	int verify_mode = SSL_VERIFY_NONE;
 	int ctx_options = 0;
 	int type;
 
@@ -167,13 +319,13 @@ static SSL_CTX *init_tls_ctx(EAP_TLS_CONF *conf)
 	if (type == SSL_FILETYPE_PEM) {
 		radlog(L_INFO, "rlm_eap_tls: Loading the certificate file as a chain");
 		if (!(SSL_CTX_use_certificate_chain_file(ctx, conf->certificate_file))) {
-			ERR_print_errors_fp(stderr);
+			radlog(L_ERR, "rlm_eap: SSL error %s", ERR_error_string(ERR_get_error(), NULL));
 			radlog(L_ERR, "rlm_eap_tls: Error reading certificate file");
 			return NULL;
 		}
 
 	} else if (!(SSL_CTX_use_certificate_file(ctx, conf->certificate_file, type))) {
-		ERR_print_errors_fp(stderr);
+		radlog(L_ERR, "rlm_eap: SSL error %s", ERR_error_string(ERR_get_error(), NULL));
 		radlog(L_ERR, "rlm_eap_tls: Error reading certificate file");
 		return NULL;
 	}
@@ -181,14 +333,14 @@ static SSL_CTX *init_tls_ctx(EAP_TLS_CONF *conf)
 
 	/* Load the CAs we trust */
 	if (!SSL_CTX_load_verify_locations(ctx, conf->ca_file, conf->ca_path)) {
-		ERR_print_errors_fp(stderr);
+		radlog(L_ERR, "rlm_eap: SSL error %s", ERR_error_string(ERR_get_error(), NULL));
 		radlog(L_ERR, "rlm_eap_tls: Error reading Trusted root CA list");
 		return NULL;
 	}
 	SSL_CTX_set_client_CA_list(ctx, SSL_load_client_CA_file(conf->ca_file));
 
 	if (!(SSL_CTX_use_PrivateKey_file(ctx, conf->private_key_file, type))) {
-		ERR_print_errors_fp(stderr);
+		radlog(L_ERR, "rlm_eap: SSL error %s", ERR_error_string(ERR_get_error(), NULL));
 		radlog(L_ERR, "rlm_eap_tls: Error reading private key file");
 		return NULL;
 	}
@@ -243,7 +395,7 @@ static SSL_CTX *init_tls_ctx(EAP_TLS_CONF *conf)
 	if (conf->check_crl) {
 	  certstore = SSL_CTX_get_cert_store(ctx);
 	  if (certstore == NULL) {
-	    ERR_print_errors_fp(stderr);
+	    radlog(L_ERR, "rlm_eap: SSL error %s", ERR_error_string(ERR_get_error(), NULL));
 	    radlog(L_ERR, "rlm_eap_tls: Error reading Certificate Store");
 	    return NULL;
 	  }
@@ -266,11 +418,21 @@ static SSL_CTX *init_tls_ctx(EAP_TLS_CONF *conf)
 
 	/* Load randomness */
 	if (!(RAND_load_file(conf->random_file, 1024*1024))) {
-		ERR_print_errors_fp(stderr);
+		radlog(L_ERR, "rlm_eap: SSL error %s", ERR_error_string(ERR_get_error(), NULL));
 		radlog(L_ERR, "rlm_eap_tls: Error loading randomness");
 		return NULL;
 	}
 
+	/*
+	 * Set the cipher list if we were told to
+	 */
+	if (conf->cipher_list) {
+		if (!SSL_CTX_set_cipher_list(ctx, conf->cipher_list)) {
+			radlog(L_ERR, "rlm_eap_tls: Error setting cipher list");
+			return NULL;
+		}
+	}
+
 	return ctx;
 }
 
@@ -394,6 +556,7 @@ static int eaptls_initiate(void *type_arg, EAP_HANDLER *handler)
 	eap_tls_t	*inst;
 	VALUE_PAIR	*vp;
 	int		client_cert = TRUE;
+	int		verify_mode = SSL_VERIFY_NONE;
 
 	inst = (eap_tls_t *)type_arg;
 
@@ -425,6 +588,17 @@ static int eaptls_initiate(void *type_arg, EAP_HANDLER *handler)
 		return 0;
 	}
 
+	/*
+	 *	Verify the peer certificate, if asked.
+	 */
+	if (client_cert) {
+		DEBUG2(" rlm_eap_tls: Requiring client certificate");
+		verify_mode = SSL_VERIFY_PEER;
+		verify_mode |= SSL_VERIFY_FAIL_IF_NO_PEER_CERT;
+		verify_mode |= SSL_VERIFY_CLIENT_ONCE;
+	}
+	SSL_set_verify(ssn->ssl, verify_mode, cbtls_verify);
+
 	/*
 	 *	Create a structure for all the items required to be
 	 *	verified for each client and set that as opaque data
