@@ -1,7 +1,7 @@
 /*
  * rlm_eap_ttls.c  contains the interfaces that are called from eap
  *
- * Version:     $Id: ttls.c,v 1.17.2.2 2005/06/03 17:13:58 aland Exp $
+ * Version:     $Id: ttls.c,v 1.17.2.2.2.1 2006/02/06 16:23:57 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
  *
  *   Copyright 2003 Alan DeKok <aland@freeradius.org>
  */
-#include "eap_tls.h"
 #include "eap_ttls.h"
 
 /*
@@ -540,13 +539,12 @@ static int vp2diameter(tls_session_t *tls_session, VALUE_PAIR *first)
 		}
 #endif
 
-		record_plus(&tls_session->clean_in, buffer, total);
+		(tls_session->record_plus)(&tls_session->clean_in, buffer, total);
 
 		/*
 		 *	FIXME: Check the return code.
 		 */
 		tls_handshake_send(tls_session);
-		record_init(&tls_session->clean_in);
 	}
 
 	/*
@@ -630,19 +628,6 @@ static int process_reply(EAP_HANDLER *handler, tls_session_t *tls_session,
 			 */
 			pairmove2(&vp, &reply->vps, PW_EAP_MESSAGE);
 			pairfree(&vp);
-
-			/*
-			 *	If we've been told to use the attributes from
-			 *	the reply, then do so.
-			 *
-			 *	WARNING: This may leak information about the
-			 *	tunneled user!
-			 */
-			if (t->use_tunneled_reply) {
-				pairdelete(&reply->vps, PW_PROXY_STATE);
-				pairadd(&request->reply->vps, reply->vps);
-				reply->vps = NULL;
-			}
 		}
 
 		/*
@@ -653,6 +638,19 @@ static int process_reply(EAP_HANDLER *handler, tls_session_t *tls_session,
 			vp2diameter(tls_session, vp);
 			pairfree(&vp);
 		}
+
+		/*
+		 *	If we've been told to use the attributes from
+		 *	the reply, then do so.
+		 *
+		 *	WARNING: This may leak information about the
+		 *	tunneled user!
+		 */
+		if (t->use_tunneled_reply) {
+			pairdelete(&reply->vps, PW_PROXY_STATE);
+			pairadd(&request->reply->vps, reply->vps);
+			reply->vps = NULL;
+		}
 		break;
 
 
@@ -874,7 +872,7 @@ int eapttls_process(EAP_HANDLER *handler, tls_session_t *tls_session)
 	 *
 	 *	I *really* don't like these 'record_t' things...
 	 */
-	data_len = record_minus(&tls_session->dirty_in, buffer, sizeof(buffer));
+	data_len = (tls_session->record_minus)(&tls_session->dirty_in, buffer, sizeof(buffer));
 	data = buffer;
 
 	/*
@@ -889,7 +887,7 @@ int eapttls_process(EAP_HANDLER *handler, tls_session_t *tls_session)
 	 *	go there, too...
 	 */
 	BIO_write(tls_session->into_ssl, buffer, data_len);
-	record_init(&tls_session->clean_out);
+	(tls_session->record_init)(&tls_session->clean_out);
 
 	/*
 	 *	Read (and decrypt) the tunneled data from the SSL session,
