@@ -157,7 +157,7 @@
  *	  a corresponding ldap_groupcmp function
  *	- Small change to ldap_get_conn to fix problems on some platforms
  */
-static const char rcsid[] = "$Id: rlm_ldap.c,v 1.122.2.8.2.5 2006/03/07 18:46:42 aland Exp $";
+static const char rcsid[] = "$Id: rlm_ldap.c,v 1.122.2.8.2.7 2006/05/08 23:45:02 aland Exp $";
 
 #include "autoconf.h"
 
@@ -464,6 +464,7 @@ ldap_instantiate(CONF_SECTION * conf, void **instance)
 
 	DEBUG("rlm_ldap: Registering ldap_groupcmp for Ldap-Group");
 	paircompare_register(PW_LDAP_GROUP, PW_USER_NAME, ldap_groupcmp, inst);
+	memset(&flags, 0, sizeof(flags));
 
 	xlat_name = cf_section_name2(conf);
 	if (xlat_name != NULL){
@@ -920,7 +921,7 @@ static int ldap_groupcmp(void *instance, REQUEST *req, VALUE_PAIR *request, VALU
                 return 1;
         }
 
-        if (!radius_xlat(basedn, sizeof(basedn), inst->basedn, req, NULL)) {
+        if (!radius_xlat(basedn, sizeof(basedn), inst->basedn, req, ldap_escape_func)) {
                 DEBUG("rlm_ldap::ldap_groupcmp: unable to create basedn.");
                 return 1;
         }
@@ -965,7 +966,7 @@ static int ldap_groupcmp(void *instance, REQUEST *req, VALUE_PAIR *request, VALU
                 ldap_msgfree(result);
         }
 
-        if(!radius_xlat(gr_filter, sizeof(gr_filter), inst->groupmemb_filt, req, NULL)){
+        if(!radius_xlat(gr_filter, sizeof(gr_filter), inst->groupmemb_filt, req, ldap_escape_func)){
                 DEBUG("rlm_ldap::ldap_groupcmp: unable to create filter.");
                 return 1;
         }
@@ -1236,7 +1237,7 @@ ldap_authorize(void *instance, REQUEST * request)
 	}
 
 	if (!radius_xlat(basedn, sizeof(basedn), inst->basedn,
-			 request, NULL)) {
+			 request, ldap_escape_func)) {
 		radlog (L_ERR, "rlm_ldap: unable to create basedn.\n");
 		return RLM_MODULE_INVALID;
 	}
@@ -1706,13 +1707,13 @@ ldap_authenticate(void *instance, REQUEST * request)
 
 	while((vp_user_dn = pairfind(request->packet->vps, PW_LDAP_USERDN)) == NULL) {
 		if (!radius_xlat(filter, sizeof(filter), inst->filter,
-				request, NULL)) {
+				request, ldap_escape_func)) {
 			radlog (L_ERR, "rlm_ldap: unable to create filter.\n");
 			return RLM_MODULE_INVALID;
 		}
 
 		if (!radius_xlat(basedn, sizeof(basedn), inst->basedn,
-		 		request, NULL)) {
+		 		request, ldap_escape_func)) {
 			radlog (L_ERR, "rlm_ldap: unable to create basedn.\n");
 			return RLM_MODULE_INVALID;
 		}
