@@ -1,6 +1,6 @@
 /*
  * otp.h
- * $Id: otp.h,v 1.28.2.3 2006/03/03 00:58:31 fcusack Exp $
+ * $Id: otp.h,v 1.28.2.6 2006/03/29 19:22:00 fcusack Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -14,10 +14,10 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  * Copyright 2001-2005 Google, Inc.
- * Copyright 2005 TRI-D Systems, Inc.
+ * Copyright 2005,2006 TRI-D Systems, Inc.
  */
 
 #ifndef OTP_H
@@ -102,6 +102,7 @@ typedef struct otp_option_t {
 #elif defined(PAM)
   /* PAM specific items */
   char *fast_prompt;	/* fast mode prompt                                */
+  int useauthtok;	/* use_first_pass                                  */
 #endif
 } otp_option_t;
 
@@ -179,7 +180,7 @@ extern int otp_x99_mac(const unsigned char *, size_t, unsigned char [8],
 /* otp_hotp.c */
 extern int otp_hotp_mac(const unsigned char [8], unsigned char [7],
                         const unsigned char [OTP_MAX_KEY_LEN], size_t,
-                        const char *);
+                        int, const char *);
 
 /* otp_util.c */
 /* Character maps for generic hex and vendor specific decimal modes */
