@@ -1,6 +1,6 @@
 /*
  * otp_cardops.c
- * $Id: otp_cardops.c,v 1.62.2.2 2006/03/03 00:58:32 fcusack Exp $
+ * $Id: otp_cardops.c,v 1.62.2.3 2006/05/09 08:13:03 fcusack Exp $
  *
  * Passcode verification functions for otp.
  *
@@ -16,14 +16,14 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  *
  * Copyright 2002-2005  Google, Inc.
  * Copyright 2005 TRI-D Systems, Inc.
  */
 
-static const char rcsid[] = "$Id: otp_cardops.c,v 1.62.2.2 2006/03/03 00:58:32 fcusack Exp $";
+static const char rcsid[] = "$Id: otp_cardops.c,v 1.62.2.3 2006/05/09 08:13:03 fcusack Exp $";
 
 #if defined(__linux__) && !defined(_GNU_SOURCE)
 #define _GNU_SOURCE	/* RTLD_DEFAULT */
@@ -147,8 +147,7 @@ otp_pw_valid(const char *username, char *challenge, const char *passcode,
   }
 
   /* Convert keystring to a keyblock. */
-  if (card_info.cardops->keystring2keyblock(card_info.keystring,
-                                            card_info.keyblock) < 0) {
+  if (card_info.cardops->keystring2keyblock(&card_info) < 0) {
     otp_log(OTP_LOG_ERR, "%s: %s: invalid key '%s' for [%s]",
             log_prefix, __func__, card_info.keystring, username);
     rc = OTP_RC_SERVICE_ERR;
