@@ -1,6 +1,6 @@
 /*
  * otp_state.c	
- * $Id: otp_state.c,v 1.23.2.2 2006/01/10 14:33:16 nbk Exp $
+ * $Id: otp_state.c,v 1.23.2.4 2006/03/06 21:40:56 fcusack Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,20 +29,19 @@
 #include <errno.h>
 #include <inttypes.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/socket.h>
-#if defined(__linux__) || defined(__APPLE__)
 #include <sys/un.h>
-#endif
 
 #include "otp.h"
 #include "otp_state.h"
 
-static const char rcsid[] = "$Id: otp_state.c,v 1.23.2.2 2006/01/10 14:33:16 nbk Exp $";
+static const char rcsid[] = "$Id: otp_state.c,v 1.23.2.4 2006/03/06 21:40:56 fcusack Exp $";
 
 
 #if defined(PAM)
