@@ -1,7 +1,7 @@
 /*
  * sql_db2.c		IBM DB2 rlm_sql driver
  *
- * Version:	$Id: sql_db2.c,v 1.4 2002/07/29 14:59:09 aland Exp $
+ * Version:	$Id: sql_db2.c,v 1.8 2004/05/01 11:31:36 phampson Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@
  * Copyright 2001  Joerg Wendland <wendland@scan-plus.de>
  */
 
-/* 
- * Modification of rlm_sql_db2 to handle IBM DB2 UDB V7 
+/*
+ * Modification of rlm_sql_db2 to handle IBM DB2 UDB V7
  * by Joerg Wendland <wendland@scan-plus.de>
  */
 
@@ -56,9 +56,15 @@ static int sql_init_socket(SQLSOCK *sqlsocket, SQL_CONFIG *config)
 	SQLRETURN retval;
 	rlm_sql_db2_sock *sock;
 
-	/* allocatE socket */
-	sqlsocket->conn = (rlm_sql_db2_sock*)rad_malloc(sizeof(rlm_sql_db2_sock));
+	/* allocate socket */
+	if (!sqlsocket->conn) {
+		sqlsocket->conn = (rlm_sql_db2_sock*)rad_malloc(sizeof(rlm_sql_db2_sock));
+		if (!sqlsocket->conn) {
+			return -1;
+		}
+	}
 	sock = sqlsocket->conn;
+	memset(sock, 0, sizeof(*sock));
 
 	/* allocate handles */
 	SQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HANDLE, &(sock->henv));
@@ -80,6 +86,21 @@ static int sql_init_socket(SQLSOCK *sqlsocket, SQL_CONFIG *config)
 	return 0;
 }
 
+
+/*************************************************************************
+ *
+ *      Function: sql_destroy_socket
+ *
+ *      Purpose: Free socket and private connection data
+ *
+ *************************************************************************/
+static int sql_destroy_socket(SQLSOCK *sqlsocket, SQL_CONFIG *config)
+{
+	free(sqlsocket->conn);
+	sqlsocket->conn = NULL;
+	return 0;
+}
+
 /*************************************************************************
  *
  *	Function: sql_query
@@ -87,7 +108,7 @@ static int sql_init_socket(SQLSOCK *sqlsocket, SQL_CONFIG *config)
  *	Purpose: Issue a query to the database
  *
  *************************************************************************/
-static int sql_query(SQLSOCK * sqlsocket, SQL_CONFIG *config, char *querystr) 
+static int sql_query(SQLSOCK * sqlsocket, SQL_CONFIG *config, char *querystr)
 {
 	SQLRETURN retval;
 	rlm_sql_db2_sock *sock;
@@ -98,7 +119,7 @@ static int sql_query(SQLSOCK * sqlsocket, SQL_CONFIG *config, char *querystr)
 		radlog(L_DBG,"query:\n%s", querystr);
 
 	/* allocate handle for statement */
-	SQLAllocHandle(SQL_HANDLE_STMT, sock->hdbc, 
+	SQLAllocHandle(SQL_HANDLE_STMT, sock->hdbc,
 			&(sock->stmt));
 
 	/* execute query */
@@ -120,7 +141,7 @@ static int sql_query(SQLSOCK * sqlsocket, SQL_CONFIG *config, char *querystr)
  *	Purpose: Issue a select query to the database
  *
  *************************************************************************/
-static int sql_select_query(SQLSOCK * sqlsocket, SQL_CONFIG *config, char *querystr) 
+static int sql_select_query(SQLSOCK * sqlsocket, SQL_CONFIG *config, char *querystr)
 {
 	return sql_query(sqlsocket, config, querystr);
 }
@@ -134,7 +155,7 @@ static int sql_select_query(SQLSOCK * sqlsocket, SQL_CONFIG *config, char *query
  *               set for the query.
  *
  *************************************************************************/
-static int sql_store_result(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_store_result(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	return 0;
 }
@@ -148,7 +169,7 @@ static int sql_store_result(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *               of columns from query
  *
  *************************************************************************/
-static int sql_num_fields(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_num_fields(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	SQLSMALLINT c;
 	rlm_sql_db2_sock *sock;
@@ -168,7 +189,7 @@ static int sql_num_fields(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *		 0 on success, -1 on failure, SQL_DOWN if 'database is down'
  *
  *************************************************************************/
-static int sql_fetch_row(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_fetch_row(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	int c, i;
 	SQLINTEGER len, slen;
@@ -210,7 +231,7 @@ static int sql_fetch_row(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *               for a result set
  *
  *************************************************************************/
-static int sql_free_result(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_free_result(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	rlm_sql_db2_sock *sock;
 	sock = sqlsocket->conn;
@@ -228,7 +249,7 @@ static int sql_free_result(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *               connection
  *
  *************************************************************************/
-static char *sql_error(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static char *sql_error(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	/* this should really be enough, if not, you still got the sqlstate */
 #define MSGLEN 512
@@ -257,7 +278,7 @@ static char *sql_error(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *               connection
  *
  *************************************************************************/
-static int sql_close(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_close(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	rlm_sql_db2_sock *sock;
 
@@ -276,7 +297,7 @@ static int sql_close(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *	Purpose: End the query, such as freeing memory
  *
  *************************************************************************/
-static int sql_finish_query(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_finish_query(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	return 0;
 }
@@ -290,7 +311,7 @@ static int sql_finish_query(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *	Purpose: End the select query, such as freeing memory or result
  *
  *************************************************************************/
-static int sql_finish_select_query(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_finish_select_query(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	return sql_finish_query(sqlsocket, config);
 }
@@ -303,7 +324,7 @@ static int sql_finish_select_query(SQLSOCK * sqlsocket, SQL_CONFIG *config)
  *	Purpose: Return the number of rows affected by the last query.
  *
  *************************************************************************/
-static int sql_affected_rows(SQLSOCK * sqlsocket, SQL_CONFIG *config) 
+static int sql_affected_rows(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 {
 	SQLINTEGER c;
 	rlm_sql_db2_sock *sock;
@@ -327,12 +348,12 @@ not_implemented(SQLSOCK * sqlsocket, SQL_CONFIG *config)
 rlm_sql_module_t rlm_sql_db2 = {
 	"rlm_sql_db2",
 	sql_init_socket,
-	not_implemented, /* sql_destroy_socket*/
+	sql_destroy_socket, /* sql_destroy_socket*/
 	sql_query,
 	sql_select_query,
 	not_implemented, /* sql_store_result */
 	sql_num_fields,
-	not_implemented,
+	not_implemented, /* sql_num_rows */
 	sql_fetch_row,
 	sql_free_result,
 	sql_error,
