@@ -2,7 +2,7 @@
  * rlm_sql.c		SQL Module
  * 		Main SQL module file. Most ICRADIUS code is located in sql.c
  *
- * Version:	$Id: rlm_sql.c,v 1.131.2.8.2.1 2005/12/13 14:11:53 nbk Exp $
+ * Version:	$Id: rlm_sql.c,v 1.131.2.8.2.2 2006/05/20 12:44:37 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  */
 
 static const char rcsid[] =
-	"$Id: rlm_sql.c,v 1.131.2.8.2.1 2005/12/13 14:11:53 nbk Exp $";
+	"$Id: rlm_sql.c,v 1.131.2.8.2.2 2006/05/20 12:44:37 nbk Exp $";
 
 #include "autoconf.h"
 
@@ -63,24 +63,8 @@ static CONF_PARSER module_config[] = {
 	 offsetof(SQL_CONFIG,sql_password), NULL, ""},
 	{"radius_db", PW_TYPE_STRING_PTR,
 	 offsetof(SQL_CONFIG,sql_db), NULL, "radius"},
-	{"acct_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_acct_table), NULL, "radacct"},
-	{"acct_table2", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_acct_table2), NULL, "radacct"},
-	{"authcheck_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_authcheck_table), NULL, "radcheck"},
-	{"authreply_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_authreply_table), NULL, "radreply"},
-	{"groupcheck_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_groupcheck_table), NULL, "radgroupcheck"},
-	{"groupreply_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_groupreply_table), NULL, "radgroupreply"},
-	{"usergroup_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_usergroup_table), NULL, "usergroup"},
 	{"nas_table", PW_TYPE_STRING_PTR,
 	 offsetof(SQL_CONFIG,sql_nas_table), NULL, "nas"},
-	{"dict_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_dict_table), NULL, "dictionary"},
 	{"sqltrace", PW_TYPE_BOOLEAN,
 	 offsetof(SQL_CONFIG,sqltrace), NULL, "no"},
 	{"sqltracefile", PW_TYPE_STRING_PTR,
@@ -127,8 +111,6 @@ static CONF_PARSER module_config[] = {
 	 offsetof(SQL_CONFIG,simul_count_query), NULL, ""},
 	{"simul_verify_query", PW_TYPE_STRING_PTR,
 	 offsetof(SQL_CONFIG,simul_verify_query), NULL, ""},
-	{"postauth_table", PW_TYPE_STRING_PTR,
-	 offsetof(SQL_CONFIG,sql_postauth_table), NULL, "radpostauth"},
 	{"postauth_query", PW_TYPE_STRING_PTR,
 	 offsetof(SQL_CONFIG,postauth_query), NULL, ""},
 	{"safe-characters", PW_TYPE_STRING_PTR,
