@@ -2,7 +2,7 @@
  *  sql.c		rlm_sql - FreeRADIUS SQL Module
  *		Main code directly taken from ICRADIUS
  *
- * Version:	$Id: sql.c,v 1.79.2.1 2005/05/20 09:13:32 nbk Exp $
+ * Version:	$Id: sql.c,v 1.79.2.3 2005/08/26 00:37:47 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -105,10 +105,11 @@ int sql_init_socketpool(SQL_INST * inst)
 		radlog(L_DBG, "rlm_sql (%s): starting %d",
 		       inst->config->xlat_name, i);
 
-		sqlsocket = rad_malloc(sizeof(SQLSOCK));
+		sqlsocket = rad_malloc(sizeof(*sqlsocket));
 		if (sqlsocket == NULL) {
 			return -1;
 		}
+		memset(sqlsocket, 0, sizeof(*sqlsocket));
 		sqlsocket->conn = NULL;
 		sqlsocket->id = i;
 		sqlsocket->state = sockunconnected;
@@ -340,6 +341,22 @@ int sql_userparse(VALUE_PAIR ** first_pair, SQL_ROW row, int querymode)
 		return -1;
 	}
 
+	/*
+	 *	Verify the 'op' field
+	 */
+	if (row[4] != NULL && row[4][0] != '\0') {
+		ptr = row[4];
+		operator = gettoken(&ptr, buf, sizeof(buf));
+	}
+	if (operator <= T_EOL) {
+		/*
+		 *  Complain about empty or invalid 'op' field
+		 */
+		operator = T_OP_CMP_EQ;
+		radlog(L_ERR, "rlm_sql: The 'op' field for attribute '%s = %s' is NULL, or non-existent.", row[2], row[3]);
+		radlog(L_ERR, "rlm_sql: You MUST FIX THIS if you want the configuration to behave as you expect.");
+	}
+
 	/*
 	 *	The 'Value' field may be empty or NULL
 	 */
@@ -352,7 +369,6 @@ int sql_userparse(VALUE_PAIR ** first_pair, SQL_ROW row, int querymode)
 	   ((row[3][0] == '\'') || (row[3][0] == '`') || (row[3][0] == '"')) &&
 	   (row[3][0] == row[3][strlen(row[3])-1])) {
 
-		value = row[3];
 		token = gettoken(&value, buf, sizeof(buf));
 		switch (token) {
 			/*
@@ -380,22 +396,6 @@ int sql_userparse(VALUE_PAIR ** first_pair, SQL_ROW row, int querymode)
 		}
 	}
 
-	/*
-	 *	Verify the 'op' field
-	 */
-	if (row[4] != NULL && row[4][0] != '\0') {
-		ptr = row[4];
-		operator = gettoken(&ptr, buf, sizeof(buf));
-	}
-	if (operator <= T_EOL) {
-		/*
-		 *  Complain about empty or invalid 'op' field
-		 */
-		operator = T_OP_CMP_EQ;
-		radlog(L_ERR, "rlm_sql: The 'op' field for attribute '%s = %s' is NULL, or non-existent.", row[2], row[3]);
-		radlog(L_ERR, "rlm_sql: You MUST FIX THIS if you want the configuration to behave as you expect.");
-	}
-
 	/*
 	 *	Create the pair
 	 */
